@@ -22,18 +22,34 @@
 #include "menu-policy.h"
 #include "panel.h"
 
+guint32 visibility_flags = 0;
+
 /* Allocate a menu cache. */
-MenuCache * panel_menu_cache_new(void)
+MenuCache * panel_menu_cache_new(guint32* visibility_flags)
 {
+    MenuCache* cache;
     if (g_getenv("XDG_MENU_PREFIX") == NULL)
         g_setenv("XDG_MENU_PREFIX", "lxde-", TRUE);
-    return menu_cache_lookup("applications.menu");
+    cache = menu_cache_lookup("applications.menu");
+    if(visibility_flags)
+    {
+        if(is_in_lxde)
+            *visibility_flags = SHOW_IN_LXDE;
+        else
+        {
+            const char* de_name = g_getenv("XDG_CURRENT_DESKTOP");
+            if(de_name)
+                *visibility_flags = menu_cache_get_desktop_env_flag(cache, de_name);
+            else
+                *visibility_flags = SHOW_IN_LXDE|SHOW_IN_GNOME|SHOW_IN_KDE|SHOW_IN_XFCE;
+        }
+    }
+    return cache;
 }
 
 /* Evaluate the visibility of a menu item. */
-gboolean panel_menu_item_evaluate_visibility(MenuCacheItem * item)
+gboolean panel_menu_item_evaluate_visibility(MenuCacheItem * item, guint32 visibility_flags)
 {
-    return menu_cache_app_get_is_visible(
-        MENU_CACHE_APP(item),
-        ((is_in_lxde) ? SHOW_IN_LXDE : SHOW_IN_LXDE | SHOW_IN_GNOME | SHOW_IN_KDE | SHOW_IN_XFCE));
+    g_debug("flags: %d\n", visibility_flags);
+    return menu_cache_app_get_is_visible(MENU_CACHE_APP(item), visibility_flags);
 }
